# Ecosystem
InversifyJS is a tiny library, but its contracts and APIs are carefully chosen to spawn an ecosystem of tools and extensions.

On this page we will only feature a few of them that the InversifyJS maintainers have vetted personally. 
Don’t let this discourage you from trying the rest of them!
Consider these the “staff picks”, and don’t hesitate to submit a PR if you’ve built something wonderful with InversifyJS.

### Utilitites
- [inversify-binding-decorators](https://github.com/inversify/inversify-binding-decorators) - Allows developers to declare lazy evaluated property injection using decorators.
- [inversify-inject-decorators](https://github.com/inversify/inversify-inject-decorators) - Allows developers to declare InversifyJS bindings using decorators.
- [inversify-express-utils](https://github.com/inversify/inversify-express-utils) - Some utilities for the development of express application with Express.
- [inversify-restify-utils](https://github.com/inversify/inversify-restify-utils) - Some utilities for the development of express application with Restify.
- [inversify-vanillajs-helpers](https://github.com/inversify/inversify-vanillajs-helpers) - Some helpers for the development of InversifyJS applications with VanillaJS or Babel.
- [inversify-tracer](https://github.com/tiagomestre/inversify-tracer) - Tool that allows the developer to trace methods of objects created by InversifyJS.
- [inversify-components](https://github.com/webcomputing/inversify-components) - Layer on top of InversifyJS that enables you to split your application into several components.
- [inversify-token](https://github.com/mscharley/inversify-token) - Token based layer for InversifyJS to enable strong type-safe guarantees for injection in TypeScript.
- [inversify-agenda](https://github.com/lautarobock/inversify-agenda) - Some utilities for the development of agenda workers with Inversify
- [inversify-graphql](https://github.com/oguimbal/inversify-graphql) - Some tools to allow developpers to inject services in their Apollo GraphQL implementations
- [react-inversify](https://github.com/org-redtea/react-inversify) - Collection of decorators and hooks for interaction with InversifyJS container within React components
- [@routex/inversify](https://github.com/routexjs/routex-inversify) - Utilities Some utilities for the developer of Routex applications with Inversify

### Middleware
- [inversify-logger-middleware](https://github.com/inversify/inversify-logger-middleware) - A console logger middleware for InversifyJS.

### Development tools
- [inversify-devtools](https://github.com/inversify/inversify-devtools) - A web application that powers the browser extensions.
- [inversify-chrome-devtools](https://github.com/inversify/inversify-chrome-devtools) - A chrome extension that aims to help developers working with InversifyJS.

### Examples
- [Basic](https://github.com/inversify/inversify-basic-example)
- [Express](https://github.com/inversify/inversify-express-example)
- [Hapi](https://github.com/inversify/inversify-hapi-example)
- [InversifyJS Binding Decorators](https://github.com/inversify/inversify-express-example/tree/master/BindingDecorators)
- Apollo GraphQL [minimal](https://github.com/oguimbal/inversify-graphql/tree/master/sample/minimal) or [advanced](https://github.com/oguimbal/inversify-graphql/tree/master/sample/complex-types)

### Open Source Projects using InversifyJS
<!-- The links are ordered alphabetically acording to the name -->
- [AssistantJS](http://assistantjs.org) - TypeScript framework to build cross-platform voice applications (alexa, google home, ...)
- [docs_gm](https://github.com/jhm-ciberman/docs_gm) - The fantastic documentation generator for GameMaker: Studio 1 and GameMaker Studio 2 projects.
- [Dwatch](https://github.com/Mercateo/dwatch) - Manage your docker containers, images and networks in a nice and clean way.
- [Frontend Boilerplates](https://boilerplates.js.org) - A collection of boilerplates to use in your projects.
- [Javascript-obfuscator](https://github.com/javascript-obfuscator/javascript-obfuscator) - JavaScript obfuscator for Node.js
- [Ninjagoat](https://www.npmjs.com/package/ninjagoat) - The not so baaaaaaad MVVM framework.
- [Prettygoat](https://www.npmjs.com/package/prettygoat) - The not so baaaaaaad Event Sourcing Projection Engine.
- [Retax](https://github.com/retaxJS) - Universal React Redux Framework.
- [RobotlegsJS](https://github.com/GoodgameStudios/RobotlegsJS) - An architecture-based framework for JavaScript/TypeScript canvas applications.
- [SugoiJS](https://github.com/sugoiJS/Demo) - TypeScript modular framework for building web server, also using inversify-express-utils.








